'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsCore = require('@lorisleiva/js-core');
var web3_js = require('@solana/web3.js');

class Web3JsRpc {
  constructor(context, endpoint, rpcOptions) {
    this.context = context;
    this.connection = new web3_js.Connection(endpoint, rpcOptions);
    this.cluster = jsCore.resolveClusterFromEndpoint(endpoint);
  }
  getEndpoint() {
    return this.connection.rpcEndpoint;
  }
  getCluster() {
    return this.cluster;
  }
  async getAccount(address) {
    const account = await this.connection.getAccountInfo(address);
    return this.parseMaybeAccount(account, address);
  }
  async call(method, params, options = {}) {
    const client = this.connection._rpcClient;
    return new Promise((resolve, reject) => {
      const callback = (error, result) => error ? reject(error) : resolve(result);
      client.request(method, params, options.id ?? null, callback);
    });
  }
  async sendTransaction(serializedTransaction, options) {
    try {
      return await this.connection.sendRawTransaction(serializedTransaction, options);
    } catch (error) {
      let resolvedError = null;
      if (error instanceof Error && 'logs' in error) {
        resolvedError = this.context.programs.resolveError(error);
      }
      throw resolvedError || error;
    }
  }
  async confirmTransaction(signature, blockhashWithExpiryBlockHeight, commitment) {
    return this.connection.confirmTransaction({
      signature,
      ...blockhashWithExpiryBlockHeight
    }, commitment);
  }
  parseMaybeAccount(account, address) {
    return account ? {
      ...account,
      exists: true,
      address,
      lamports: jsCore.lamports(account.lamports)
    } : {
      exists: false,
      address
    };
  }
}

exports.Web3JsRpc = Web3JsRpc;
//# sourceMappingURL=Web3JsRpc.cjs.map
